#
# spec file for package sqlite3
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sqlite3
Version:        3.7.17
Release:        2.3.1
%define tarversion 3071700
Summary:        Embeddable SQL Database Engine
License:        SUSE-Public-Domain
Group:          Productivity/Databases/Servers
Url:            http://www.sqlite.org/
#
BuildRequires:  pkg-config
BuildRequires:  readline-devel
%if 0%{?suse_version:1}
BuildRequires:  update-desktop-files
%endif
#
Requires:       libsqlite3-0 = %version
Provides:       sqlite = %version
Obsoletes:      sqlite < %version
Source0:        http://www.sqlite.org/2013/sqlite-autoconf-%tarversion.tar.gz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      sqlite-64bit
%endif
#
%description
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is a server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.

%package -n libsqlite3-0
Summary:        Shared libraries for the Embeddable SQL Database Engine
Group:          Development/Libraries/C and C++

%description -n libsqlite3-0
This package contains the shared libraries for the Embeddable SQL
Database Engine.

SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server. SQLite is a server and the SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command line tool or via any
application that supports the Qt database plug-ins.

%package devel
Summary:        Embeddable SQL Database Engine
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libsqlite3-0 = %version
Provides:       sqlite-devel = %version
Obsoletes:      sqlite-devel < %version

%description devel
SQLite is a C library that implements an embeddable SQL database
engine. Programs that link with the SQLite library can have SQL
database access without running a separate RDBMS process.

SQLite is not a client library used to connect to a big database
server; SQLite is the server. The SQLite library reads and writes
directly to and from the database files on disk.

SQLite can be used via the sqlite command-line tool or via any
application which supports the Qt database plug-ins.

%prep
%setup -q -n sqlite-autoconf-%tarversion

%build
export CFLAGS="%optflags -DSQLITE_ENABLE_COLUMN_METADATA -DSQLITE_ENABLE_FTS4"
%configure --disable-static
make

%install
make install DESTDIR=%buildroot
rm %buildroot/%_libdir/*.la

%post -n libsqlite3-0 -p /sbin/ldconfig

%postun -n libsqlite3-0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
/usr/bin/sqlite3
%doc %_mandir/man1/*

%files -n libsqlite3-0
%defattr(-,root,root)
%_libdir/libsqlite*.so.*

%files devel
%defattr(-,root,root)
/usr/include/*.h
%_libdir/libsqlite*.so
%_libdir/pkgconfig/sqlite3.pc

%changelog
* Mon Aug 12 2013 max@suse.com
- The Tcl bindings for SQLite are now part of the Tcl core, so the
  sqlite3-tcl subpackage is no longer needed.
* Wed Mar 20 2013 max@suse.com
- New Version 3.7.16:
  * Added the PRAGMA foreign_key_check command.
  * Added new extended error codes for all SQLITE_CONSTRAINT
    errors
  * Added the SQLITE_READONLY_ROLLBACK extended error code for
    when a database cannot be opened because it needs rollback
    recovery but is read-only.
  * Added SQL functions unicode(A) and char(X1,...,XN).
  * Performance improvements for PRAGMA incremental_vacuum,
    especially in cases where the number of free pages is greater
    than what will fit on a single trunk page of the freelist.
  * Improved optimization of queries containing aggregate min() or
    max().
  * Enhance virtual tables so that they can potentially use an
    index when the WHERE clause contains the IN operator.
  * Allow indices to be used for sorting even if prior terms of
    the index are constrained by IN operators in the WHERE clause.
  * Enhance the PRAGMA table_info command so that the "pk" column
    is an increasing integer to show the order of columns in the
    primary key.
  * Enhance the query optimizer to exploit transitive join
    constraints.
  * Performance improvements in the query optimizer.
  * Allow the error message from PRAGMA integrity_check to be
    longer than 20000 bytes.
  * Improved name resolution for deeply nested queries.
  * Added the test_regexp.c module as a demonstration of how to
    implement the REGEXP operator.
  * Improved error messages in the RTREE extension.
  * Enhance the command-line shell so that a non-zero argument to
    the ".exit" command causes the shell to exit immediately
    without cleanly shutting down the database connection.
  * Improved error messages for invalid boolean arguments to
    dot-commands in the command-line shell.
  * Improved error messages for "foreign key mismatch" showing the
    names of the two tables involved.
  * Remove all uses of umask() in the unix VFS.
  * Added the PRAGMA vdbe_addoptrace and PRAGMA vdbe_debug
    commands.
  * Change to use strncmp() or the equivalent instead of memcmp()
    when comparing non-zero-terminated strings.
  * Update cygwin interfaces to omit deprecated API calls.
  * Enhance the spellfix1 extension so that the edit distance cost
    table can be changed at runtime by inserting a string like
    'edit_cost_table=TABLE' into the "command" field.
  * Bug fix: repair a long-standing problem that could cause
    incorrect query results in a 3-way or larger join that
    compared INTEGER fields against TEXT fields in two or more
    places. Ticket fc7bd6358f
  * Bug fix: Issue an error message if the 16-bit reference
    counter on a view overflows due to an overly complex query.
  * Bug fix: Avoid leaking memory on LIMIT and OFFSET clauses in
    deeply nested UNION ALL queries.
  * Bug fix: Make sure the schema is up-to-date prior to running
    pragmas table_info, index_list, index_info, and
    foreign_key_list.
* Thu Jan 24 2013 max@suse.com
- New Version 3.7.15.2:
  * Added the sqlite3_errstr() interface.
  * Avoid invoking the sqlite3_trace() callback multiple times
    when a statement is automatically reprepared due to
    SQLITE_SCHEMA errors.
  * Enhance IN operator processing to make use of indices with
    numeric affinities.
  * Do full-table scans using covering indices when possible,
    under the theory that an index will be smaller and hence can
    be scanned with less I/O.
  * Enhance the query optimizer so that ORDER BY clauses are more
    aggressively optimized, especially in joins where various
    terms of the ORDER BY clause come from separate tables of the
    join.
  * Add the ability to implement FROM clause subqueries as
    coroutines rather that manifesting the subquery into a
    temporary table.
  * Several enhancements the command-line shell.
  * Added the busy_timeout pragma.
  * Added the instr() SQL function.
  * Added the SQLITE_FCNTL_BUSYHANDLER file control, used to allow
    VFS implementations to get access to the busy handler
    callback.
  * The xDelete method in the built-in VFSes now return
    SQLITE_IOERR_DELETE_NOENT if the file to be deleted does not
  * exist.
  * Bug fix: Avoid various concurrency problems in shared cache
    mode.
  * Bug fix: Avoid a deadlock or crash if the backup API, shared
    cache, and the SQLite Encryption Extension are all used at
    once.
  * Bug fix: SQL functions created using the TCL interface honor
    the "nullvalue" setting.
  * Bug fix: Fix a 32-bit overflow problem on CREATE INDEX for
    databases larger than 16GB.
  * Bug fix: Avoid segfault when using the COLLATE operator inside
    of a CHECK constraint or view in shared cache mode.
- Use %%optflags for building
- Fix debuginfo in the Tcl bindings.
* Fri Oct  5 2012 max@suse.com
- Bugfix release 3.7.14.1:
  * Fix a bug that causes a segfault on a LEFT JOIN that includes
    an OR in the ON clause.
  * Work around a bug in the optimizer in the VisualStudio-2012
    compiler that causes invalid code to be generated when
    compiling SQLite on ARM.
  * Fix the TCL interface so that the "nullvalue" setting is
    honored for TCL implementations of SQL functions.
* Tue Sep  4 2012 mmeister@suse.com
- New version 3.7.14:
  * Ensure that floating point values are preserved exactly when
    reconstructing a database from the output of the ".dump"
    command of the command-line shell.
  * Added the sqlite3_close_v2() interface.
  * Updated the command-line shell so that it can be built using
    SQLITE_OMIT_FLOATING_POINT and SQLITE_OMIT_AUTOINIT.
  * Enhancements to PRAGMA integrity_check and PRAGMA quick_check
    so that they can optionally check just a single attached
    database install of all attached databases.
  * Enhancements to WAL mode processing that ensure that at least
    one valid read-mark is available at all times, so that
    read-only processes can always read the database.
  * Performance enhancements in the sorter used by ORDER BY and CREATE INDEX.
  * Added the SQLITE_DISABLE_FTS4_DEFERRED compile-time option.
  * Better handling of aggregate queries where the aggregate
    functions are contained within subqueries.
  * Enhance the query planner so that it will try to use a
    covering index on queries that make use of or optimization.
* Fri Aug 31 2012 max@suse.com
- New version 3.7.13:
  * In-memory databases that are specified using URI filenames are
    allowed to use shared cache, so that the same in-memory
    database can be accessed from multiple database connections.
  * Recognize and use the mode=memory query parameter in URI
    filenames.
  * Avoid resetting the schema of shared cache connections when
    any one connection closes. Instead, wait for the last
    connection to close before reseting the schema.
  * In the RTREE extension, when rounding 64-bit floating point
    numbers to 32-bit for storage, always round in a direction
    that causes the bounding box to get larger.
  * Adjust the unix driver to avoid unnecessary calls to fchown().
  * Add interfaces sqlite3_quota_ferror() and
    sqlite3_quota_file_available() to the test_quota.c module.
  * The sqlite3_create_module() and sqlite3_create_module_v2()
    interfaces return SQLITE_MISUSE on any attempt to overload or
    replace a virtual table module. The destructor is always
    called in this case, in accordance with historical and current
    documentation.
* Thu May 24 2012 max@suse.com
- New version 3.7.12:
  * Add the SQLITE_DBSTATUS_CACHE_WRITE option for
    sqlite3_db_status().
  * Optimize the typeof() and length() SQL functions so that they
    avoid unnecessary reading of database content from disk.
  * Add the FTS4 "merge" command, the FTS4 "automerge" command,
    and the FTS4 "integrity-check" command.
  * Report the name of specific CHECK constraints that fail.
  * In the command-line shell, use popen() instead of fopen() if
    the first character of the argument to the ".output" command
    is "|".
  * Make use of OVERLAPPED in the windows VFS to avoid some system
    calls and thereby obtain a performance improvement.
  * More aggressive optimization of the AND operator when one side
    or the other is always false.
  * Improved performance of queries with many OR-connected terms
    in the WHERE clause that can all be indexed.
  * Add the SQLITE_RTREE_INT_ONLY compile-time option to force the
    R*Tree Extension Module to use integer instead of floating
    point values for both storage and computation.
  * Enhance the PRAGMA integrity_check command to use much less
    memory when processing multi-gigabyte databases.
  * New interfaces added to the test_quota.c add-on module.
  * Added the ".trace" dot-command to the command-line shell.
  * Allow virtual table constructors to be invoked recursively.
  * Improved optimization of ORDER BY clauses on compound queries.
  * Improved optimization of aggregate subqueries contained within
    an aggregate query.
  * Bug fix: Fix the RELEASE command so that it does not cancel
    pending queries. This repairs a problem introduced in 3.7.11.
  * Bug fix: Do not discard the DISTINCT as superfluous unless a
    subset of the result set is subject to a UNIQUE constraint and
    it none of the columns in that subset can be NULL. Ticket
    385a5b56b9.
  * Bug fix: Do not optimize away an ORDER BY clause that has the
    same terms as a UNIQUE index unless those terms are also NOT
    NULL. Ticket 2a5629202f.
- 79a4a3a84f.patch isn't needed anymore.
* Mon May 14 2012 idonmez@suse.com
- Add upstream commit 79a4a3a84f to fix subversion failures
* Fri May  4 2012 max@suse.com
- Spec file cleanup
- Drop support for the pre 11.0 packaging scheme.
- New version 3.7.11. Changes since 3.7.8 include:
  * Enhance the INSERT syntax to allow multiple rows to be inserted
    via the VALUES clause.
  * Enhance the CREATE VIRTUAL TABLE command to support the IF NOT
    EXISTS clause.
  * Added the sqlite3_stricmp() interface as a counterpart to
    sqlite3_strnicmp().
  * Added the sqlite3_db_readonly() interface.
  * Added the SQLITE_FCNTL_PRAGMA file control, giving VFS
    implementations the ability to add new PRAGMA statements or to
    override built-in PRAGMAs.
  * Queries of the form: "SELECT max(x), y FROM table" returns the
    value of y on the same row that contains the maximum x value.
  * Added support for the FTS4 languageid option.
  * Documented support for the FTS4 content option. This feature
    has actually been in the code since version 3.7.9 but is only
    now considered to be officially supported.
  * Pending statements no longer block ROLLBACK. Instead, the
    pending statement will return SQLITE_ABORT upon next access
    after the ROLLBACK.
  * Improvements to the handling of CSV inputs in the command-line
    shell
  * The default schema format number is changed from 1 to 4. This
    means that, unless the PRAGMA legacy_file_format=ON statement
    is run, newly created database files will be unreadable by
    version of SQLite prior to 3.3.0 (2006-01-10). It also means
    that the descending indices are enabled by default.
  * The sqlite3_pcache_methods structure and the
    SQLITE_CONFIG_PCACHE and SQLITE_CONFIG_GETPCACHE configuration
    parameters are deprecated. They are replaced by a new
    sqlite3_pcache_methods2 structure and SQLITE_CONFIG_PCACHE2 and
    SQLITE_CONFIG_GETPCACHE2 configuration parameters.
  * Added the powersafe overwrite property to the VFS
    interface. Provide the SQLITE_IOCAP_POWERSAFE_OVERWRITE I/O
    capability, the SQLITE_POWERSAFE_OVERWRITE compile-time option,
    and the "psow=BOOLEAN" query parameter for URI filenames.
  * Added the sqlite3_db_release_memory() interface and the
    shrink_memory pragma.
  * Added the sqlite3_db_filename() interface.
  * Added the sqlite3_stmt_busy() interface.
  * Added the sqlite3_uri_boolean() and sqlite3_uri_int64()
    interfaces.
  * If the argument to PRAGMA cache_size is negative N, that means
    to use approximately -1024*N bytes of memory for the page cache
    regardless of the page size.
  * Enhanced the default memory allocator to make use of _msize()
    on windows, malloc_size() on Mac, and malloc_usable_size() on
    Linux.
  * Enhanced the query planner to support index queries with range
    constraints on the rowid.
  * Enhanced the query planner flattening logic to allow UNION ALL
    compounds to be promoted upwards to replace a simple wrapper
    SELECT even if the compounds are joins.
  * Enhanced the query planner so that the xfer optimization can be
    used with INTEGER PRIMARY KEY ON CONFLICT as long as the
    destination table is initially empty.
  * Enhanced the windows VFS so that all system calls can be
    overridden using the xSetSystemCall interface.
  * Updated the "unix-dotfile" VFS to use locking directories with
    mkdir() and rmdir() instead of locking files with open() and
    unlink().
  * Enhancements to the test_quota.c extension to support
    stdio-like interfaces with quotas.
  * Change the unix VFS to be tolerant of read() system calls that
    return less then the full number of requested bytes.
  * Change both unix and windows VFSes to report a sector size of
    4096 instead of the old default of 512.
  * In the TCL Interface, add the -uri option to the "sqlite3" TCL
    command used for creating new database connection objects.
  * Added the SQLITE_TESTCTRL_EXPLAIN_STMT test-control option with
    the SQLITE_ENABLE_TREE_EXPLAIN compile-time option to enable
    the command-line shell to display ASCII-art parse trees of SQL
    statements that it processes, for debugging and analysis.
  * Bug fix: Add an additional xSync when restarting a WAL in order
    to prevent an exceedingly unlikely but theoretically possible
    database corruption following power-loss. Ticket ff5be73dee.
  * Bug fix: Change the VDBE so that all registers are initialized
    to Invalid instead of NULL. Ticket 7bbfb7d442
  * Bug fix: Fix problems that can result from 32-bit integer
    overflow. Ticket ac00f496b7e2
  * If a search token (on the right-hand side of the MATCH
    operator) in FTS4 begins with "^" then that token must be the
    first in its field of the document. ** Potentially Incompatible
    Change **
  * Added options SQLITE_DBSTATUS_CACHE_HIT and
    SQLITE_DBSTATUS_CACHE_MISS to the sqlite3_db_status()
    interface.
  * Removed support for SQLITE_ENABLE_STAT2, replacing it with the
    much more capable SQLITE_ENABLE_STAT3 option.
  * Enhancements to the sqlite3_analyzer utility program, including
    the --pageinfo and --stats options and support for multiplexed
    databases.
  * Enhance the sqlite3_data_count() interface so that it can be
    used to determine if SQLITE_DONE has been seen on the prepared
    statement.
  * Added the SQLITE_FCNTL_OVERWRITE file-control by which the
    SQLite core indicates to the VFS that the current transaction
    will overwrite the entire database file.
  * Increase the default lookaside memory allocator allocation size
    from 100 to 128 bytes.
  * Enhanced the query planner so that it can factor terms in and
    out of OR expressions in the WHERE clause in an effort to find
    better indices.
  * Added the SQLITE_DIRECT_OVERFLOW_READ compile-time option,
    causing overflow pages to be read directly from the database
    file, bypassing the page cache.
  * Remove limits on the magnitude of precision and width value in
    the format specifiers of the sqlite3_mprintf() family of string
    rendering routines.
  * Fix a bug that prevent ALTER TABLE ... RENAME from working on
    some virtual tables in a database with a UTF16 encoding.
  * Fix a bug in ASCII-to-float conversion that causes slow
    performance and incorrect results when converting numbers with
    ridiculously large exponents.
  * Fix a bug that causes incorrect results in aggregate queries
    that use multiple aggregate functions whose arguments contain
    complicated expressions that differ only in the case of string
  * literals contained within those expressions.
  * Fix a bug that prevented the page_count and quick_check pragmas
    from working correctly if their names were capitalized.
  * Fix a bug that caused VACUUM to fail if the count_changes
    pragma was engaged.
  * Fix a bug in virtual table implementation that causes a crash
    if an FTS4 table is dropped inside a transaction and a
    SAVEPOINT occurs afterwards.
* Thu Apr 26 2012 behrisch@users.sourceforge.net
- fixing tcl macro for old or non-SuSE builds
* Fri Oct  7 2011 max@suse.com
- New version 3.7.8:
  * Orders of magnitude performance improvement for CREATE INDEX on
    very large tables.
  * Improved the windows VFS to better defend against interference
    from anti-virus software.
  * Improved query plan optimization when the DISTINCT keyword is
    present.
  * Allow more system calls to be overridden in the unix VFS - to
    provide better support for chromium sandboxes.
  * Increase the default size of a lookahead cache line from 100 to
    128 bytes.
  * Enhancements to the test_quota.c module so that it can track
    preexisting files.
  * Bug fix: Virtual tables now handle IS NOT NULL constraints
    correctly.
  * Bug fixes: Correctly handle nested correlated subqueries used
    with indices in a WHERE clause.
- Re-integrate the Tcl bidings as a subpackage, now that it is
  easier to build both out of a single tarball.
* Thu Aug  4 2011 idonmez@novell.com
- New Version: 3.7.7.1:
  * Fix a bug causing PRAGMA case_sensitive_like statements compiled
    using sqlite3_prepare() to fail with an SQLITE_SCHEMA error.
* Fri Jun 24 2011 max@novell.com
- New Version: 3.7.7:
  * Add support for URI filenames.
  * Add the sqlite3_vtab_config() interface in support of
    ON CONFLICT clauses with virtual tables.
  * Add the xSavepoint, xRelease and xRollbackTo methods in
    virtual tables in support of SAVEPOINT for virtual tables.
  * Update the built-in FTS3/FTS4 and RTREE virtual tables to
    support ON CONFLICT clauses and REPLACE.
  * Avoid unnecessary reparsing of the database schema.
  * Added support for the FTS4 prefix option and the FTS4 order
    option.
  * Allow WAL-mode databases to be opened read-only as long as
    there is an existing read/write connection.
  * Added support for short filenames.
* Fri May 20 2011 max@novell.com
- New Version: 3.7.6.3:
  * Fix a problem with WAL mode which could cause transactions to
    silently rollback if the cache_size is set very small (less than
    10) and SQLite comes under memory pressure.
- Enabled the column metadata APIs (bnc#383370).
* Wed Apr 13 2011 max@novell.com
- New Version: 3.7.6.1:
  * Added the sqlite3_wal_checkpoint_v2() interface and enhanced
    the wal_checkpoint pragma to support blocking checkpoints.
  * Improvements to the query planner so that it makes better
    estimates of plan costs and hence does a better job of
    choosing the right plan, especially when SQLITE_ENABLE_STAT2
    is used.
  * Fix a bug which prevented deferred foreign key constraints
    from being enforced when sqlite3_finalize() was not called
    by one statement with a failed foreign key constraint prior
    to another statement with foreign key constraints running.
  * Integer arithmetic operations that would have resulted in
    overflow are now performed using floating-point instead.
  * Increased the version number on the VFS object to 3 and added
    new methods xSetSysCall, xGetSysCall, and xNextSysCall used
    for doing full-coverage testing.
  * Increase the maximum value of SQLITE_MAX_ATTACHED from 30 to
    62 (though the default value remains at 10).
  * Added the fts4aux table
  * Added support for compressed FTS4 content
  * Enhance the ANALYZE command to support the name of an index as
    its argument, in order to analyze just that one index.
  * Added the "unix-excl" built-in VFS on unix and unix-like
    platforms.
* Thu Feb  3 2011 max@novell.com
- New Version: 3.7.5:
  * Added the sqlite3_vsnprintf() interface.
  * Added the SQLITE_DBSTATUS_LOOKASIDE_HIT,
    SQLITE_DBSTATUS_LOOKASIDE_MISS_SIZE, and
    SQLITE_DBSTATUS_LOOKASIDE_MISS_FULL options for the
    sqlite3_db_status() interface.
  * Added the SQLITE_OMIT_AUTORESET compile-time option.
  * Added the SQLITE_DEFAULT_FOREIGN_KEYS compile-time option.
  * Updates to sqlite3_stmt_readonly() so that its result is
    well-defined for all prepared statements and so that it works
    with VACUUM.
  * Added the "-heap" option to the command-line shell
  * Fix a bug involving frequent changes in and out of WAL mode
    and VACUUM that could (in theory) cause database corruption.
  * Enhance the sqlite3_trace() mechanism so that nested SQL
    statements such as might be generated by virtual tables are
    shown but are shown in comments and without parameter
    expansion. This greatly improves tracing output when using the
    FTS3/4 and/or RTREE virtual tables.
  * Change the xFileControl() methods on all built-in VFSes to
    return SQLITE_NOTFOUND instead of SQLITE_ERROR for an
    unrecognized operation code.
  * The SQLite core invokes the SQLITE_FCNTL_SYNC_OMITTED file
    control to the VFS in place of a call to xSync if the database
    has PRAGMA synchronous set to OFF.
- Split off sqlite3-tcl into a separate source package.
* Thu Jan 13 2011 max@novell.com
- Adjust the package to the new upstream tarball naming and
  version numbering scheme.
- New version: 3.7.4:
  * Added the sqlite3_blob_reopen() interface to allow an
    existing sqlite3_blob object to be rebound to a new row.
  * Use the new sqlite3_blob_reopen() interface to improve the
    performance of FTS.
  * VFSes that do not support shared memory are allowed to access
    WAL databases if PRAGMA locking_mode is set to EXCLUSIVE.
  * Enhancements to EXPLAIN QUERY PLAN.
  * Added the sqlite3_stmt_readonly() interface.
  * Added PRAGMA checkpoint_fullfsync.
  * Added the SQLITE_FCNTL_FILE_POINTER option to
    sqlite3_file_control().
  * Added support for FTS4 and enhancements to the FTS matchinfo()
    function.
  * Added the test_superlock.c module which provides example code
    for obtaining an exclusive lock to a rollback or WAL database.
  * Added the test_multiplex.c module which provides an example
    VFS that provides multiplexing (sharding) of a DB, splitting
    it over multiple files of fixed size.
  * A very obscure bug associated with the or optimization was
    fixed.
* Wed Nov 17 2010 max@novell.com
- New version: 3.7.3:
  * Added the sqlite3_create_function_v2() interface that
    includes a destructor callback.
  * Added support for custom r-tree queries using
    application-supplied callback routines to define the boundary
    of the query region.
  * The default page cache strives more diligently to avoid using
    memory beyond what is allocated to it by
    SQLITE_CONFIG_PAGECACHE. Or if using page cache is allocating
    from the heap, it strives to avoid going over the
    sqlite3_soft_heap_limit64(), even if
    SQLITE_ENABLE_MEMORY_MANAGEMENT is not set.
  * Added the sqlite3_soft_heap_limit64() interface as a
    replacement for sqlite3_soft_heap_limit().
  * The ANALYZE command now gathers statistics on tables even if
    they have no indices.
  * Tweaks to the query planner to help it do a better job of
    finding the most efficient query plan for each query.
  * Enhanced the internal text-to-numeric conversion routines so
    that they work with UTF8 or UTF16, thereby avoiding some
    UTF16-to-UTF8 text conversions.
  * Fix a problem that was causing excess memory usage with large
    WAL transactions in win32 systems.
  * The interface between the VDBE and B-Tree layer is enhanced
    such that the VDBE provides hints to the B-Tree layer letting
    the B-Tree layer know when it is safe to use hashing instead
    of B-Trees for transient tables.
  * Miscellaneous documentation enhancements.
* Fri Aug 27 2010 max@novell.com
- New version: 3.7.2:
  * Added new commands SQLITE_DBSTATUS_SCHEMA_USED and
    SQLITE_DBSTATUS_STMT_USED to the sqlite3_db_status()
    interface, in order to report out the amount of memory used
    to hold the schema and prepared statements of a connection.
  * Increase the maximum size of a database pages from 32KiB to
    64KiB.
  * Use the LIKE optimization even if the right-hand side string
    contains no wildcards.
  * Added the SQLITE_FCNTL_CHUNK_SIZE verb to the
    sqlite3_file_control() interface for both unix and windows, to
    cause database files to grow in large chunks in order to reduce
    disk fragmentation.
  * Fixed a bug in the query planner that caused performance
    regresssions relative to 3.6.23.1 on some complex joins.
  * Fixed a typo in the OS/2 backend.
  * Refactored the pager module.
  * The SQLITE_MAX_PAGE_SIZE compile-time option is now silently
    ignored. The maximum page size is hard-coded at 65536 bytes.
  * Fix an old and very obscure bug that can lead to corruption of
    the database free-page list when incremental_vacuum is used.
* Thu Aug  5 2010 max@suse.de
- New version 3.7.0.1:
  * Fix a potential database corruption problem that can result
    if the same database file is alternately written by version
    3.7.0 and 3.6.23.1.
  * Fix a possible performance regression caused by the
    introduction of automatic indexing.
* Thu Jul 22 2010 max@suse.de
- New version: 3.7.0:
  * Added support for write-ahead logging.
  * Query planner enhancement - automatic transient indices are
    created when doing so reduces the estimated query time.
  * Query planner enhancement - the ORDER BY becomes a no-op if
    the query also contains a GROUP BY clause that forces the
    correct output order.
  * Add the SQLITE_DBSTATUS_CACHE_USED verb for
    sqlite3_db_status().
  * The logical database size is now stored in the database
    header so that bytes can be appended to the end of the
    database file without corrupting it and so that SQLite will
    work correctly on systems that lack support for ftruncate().
* Mon Jul  5 2010 max@suse.de
- Bugfix release: 3.6.23.1
  * Fix a bug in the offsets() function of FTS3.
  * Fix a missing "sync" that when omitted could lead to database
    corruption if a power failure or OS crash occurred just as a
    ROLLBACK operation was finishing.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Wed Mar 10 2010 max@suse.de
- Version 3.6.23:
  * Added the secure_delete pragma.
  * Added the sqlite3_compileoption_used() and
    sqlite3_compileoption_get() interfaces as well as the
    compile_options pragma and the sqlite_compileoption_used() and
    sqlite_compileoption_get() SQL functions.
  * Added the sqlite3_log() interface together with the
    SQLITE_CONFIG_LOG verb to sqlite3_config(). The ".log" command
    is added to the Command Line Interface.
  * Improvements to FTS3.
  * Improvements and bug-fixes in support for
    SQLITE_OMIT_FLOATING_POINT.
  * The integrity_check pragma is enhanced to detect out-of-order
    rowids.
  * The ".genfkey" operator has been removed from the Command Line
    Interface.
  * Updates to the co-hosted Lemon LALR(1) parser
    generator. (These updates did not effect SQLite.)
  * Various minor bug fixes and performance enhancements.
* Wed Jan 20 2010 max@suse.de
- Add -fno-strict-aliasing to CFLAGS as a temporary workaround
  for a crash on (at least) PPC (bnc#571934).
* Thu Jan 14 2010 max@novell.com
- New version: 3.6.22:
  * Fix bugs that can (rarely) lead to incorrect query results
    when the CAST or OR operators are used in the WHERE clause of
    a query.
  * Continuing enhancements and improvements to FTS3.
  * The SQL output resulting from sqlite3_trace() is now modified
    to include the values of bound parameters.
  * Performance optimizations targetting a specific use case from
    a single high-profile user of SQLite. A 12%% reduction in the
    number of CPU operations is achieved (as measured by
    valgrind). Actual performance improvements in practice may
    vary depending on workload. Changes include:
  * The ifnull() and coalesce() SQL functions are now
    implemented using in-line VDBE code rather than calling
    external functions, so that unused arguments need never be
    evaluated.
  * The substr() SQL function does not bother to measure the
    length its entire input string if it is only computing a
    prefix.
  * Unnecessary OP_IsNull, OP_Affinity, and OP_MustBeInt VDBE
    opcodes are suppressed.
  * Various code refactorizations for performance.
  * The FTS3 extension has undergone a major rework and
    cleanup. New FTS3 documentation is now available.
  * The SQLITE_SECURE_DELETE compile-time option fixed to make
    sure that content is deleted even when the truncate
    optimization applies.
  * Improvements to "dot-command" handling in the Command Line
    Interface.
  * Other minor bug fixes and documentation enhancements.
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Nov 30 2009 max@suse.de
- New version: 3.6.20.
- Reworked package to use the "amalgamation" source distribution
  as recommended by the author and to fix the following bugs:
  * bnc#555845: sqlite3 should link libdl
  * bnc#470371: system sqlite should be built with fts3
* Thu Oct 22 2009 andrea@opensuse.org
- enabled load-extension option since some packages need
  such symbol
* Wed Aug  5 2009 max@suse.de
- New version: 3.6.16:
  * Fix a bug (ticket #3929) that occasionally causes INSERT or
    UPDATE operations to fail on an indexed table that has a
    self-modifying trigger.
  * Refactor the internal representation of SQL expressions so
    that  they use less memory on embedded platforms.
  * Reduce the amount of stack space used
  * The sqlite3_create_function() family of interfaces now return
    SQLITE_MISUSE instead of SQLITE_ERROR when passed invalid
    parameter combinations.
  * When new tables are created using CREATE TABLE ... AS SELECT
    ... the datatype of the columns is the simplified SQLite
    datatype (TEXT, INT, REAL, NUMERIC, or BLOB) instead of a
    copy of the original datatype from the source table.
  * Resolve race conditions when checking for a hot rollback
    journal.
  * The sqlite3_shutdown() interface frees all mutexes under
    windows.
  * Enhanced robustness against corrupt database files
  * Continuing improvements to the test suite and fixes to
    obscure bugs and inconsistencies that the test suite
    improvements are uncovering.
  * Other minor bug fixes and performance optimizations.
* Tue Jun  2 2009 max@suse.de
- New version 3.6.14.2:
  * Fix a code generator bug introduced in version 3.6.14. This bug
    can cause incorrect query results under obscure circumstances.
- Use the old naming scheme when building on openSUSE < 11.0.
* Sun Feb 22 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Oct 24 2008 max@suse.de
- Update to version 3.6.4:
  * Fixes a missing symbol with the Tcl binding.
  * Added the sqlite3_stmt_status() interface for performance
    monitoring.
  * Added the TRUNCATE option to PRAGMA journal_mode
  * Performance enhancements to tree balancing logic in the B-Tree
    layer.
  * Added the source code and documentation for the genfkey
    program for automatically generating triggers to enforce
    foreign key constraints.
  * The SQL language documentation is converted to use syntax
    diagrams instead of BNF.
  * Other minor bug fixes
* Fri Sep 26 2008 max@suse.de
- Bugfix-Release 3.6.3:
  * Fix for a bug in the SELECT DISTINCT logic that was introduced
    by the prior versoin.
  * Other minor bug fixes.
* Wed Sep 10 2008 max@suse.de
- Update to version 3.6.2.
- This version contains rewrites of the page-cache subsystem and
  the procedures for matching identifiers to table columns in SQL
  statements. These changes are designed to better modularize the
  code and make it more maintainable and reliable moving forward.
  Nearly 5000 non-comment lines of core code (about 11.3%%) have
  changed from the previous release. Nevertheless, there should
  be no application-visible changes, other than bug fixes.
* Fri Jul 25 2008 max@suse.de
- Update to version 3.6.0:
  * Modifications to the virtual file system interface to support a
    wider range of embedded systems. See 35to36.html for additional
    information. *** Potentially incompatible change ***
  * The handling of IN and NOT IN operators that contain a NULL on
    their right-hand side expression is brought into compliance with
    the SQL standard and with other SQL database engines. This is a
    bug fix, but as it has the potential to break legacy applications
    that depend on the older buggy behavior, we mark that as a
  * ** Potentially incompatible change ***
  * The result column names generated for compound subqueries have
    been simplified to show only the name of the column of the
    original table and omit the table name. This makes SQLite
    operate more like other SQL database engines.
  * Added the sqlite3_config() interface for doing run-time
    configuration of the entire SQLite library.
  * Added the sqlite3_status() interface used for querying run-time
    status information about the overall SQLite library and its
    subsystems.
  * Added the sqlite3_initialize() and sqlite3_shutdown() interfaces.
  * The SQLITE_OPEN_NOMUTEX option was added to sqlite3_open_v2().
  * Added the PRAGMA page_count command.
  * Added the sqlite3_next_stmt() interface.
  * Added a new R*Tree virtual table
- Link libtclsqlite against the Tcl stubs library, so that it can be
  used from tclkit.
* Thu May  8 2008 max@suse.de
- Actually apply sqlite-strcasecmp.patch to fix the Tcl extension.
- Link the Tcl extension dynamically.
* Wed May  7 2008 coolo@suse.de
- provide sqlite-<arch>
* Tue Apr 29 2008 cthiel@suse.de
- obsolete sqlite-<arch> via baselibs.conf
* Mon Apr 28 2008 max@suse.de
- Avoid an unresolved symbol in the Tcl extension
  (sqlite-strcasecmp.patch).
- Use upstream fixes for test failures caused by Tcl 8.5
* Sun Apr 27 2008 coolo@suse.de
- disable the test suite, it adds 5 hours to the build time
* Thu Apr 10 2008 max@suse.de
- update to version 3.5.7. Changes include:
  * Fix a bug in the register allocation for compound selects.
  * Do not apply the flattening optimization if the outer query
    is an aggregate and the inner query contains ORDER BY.
  * Accept "Z" as the zulu timezone at the end of date strings.
  * Fix a bug in the LIKE optimizer that occurs when the last
    character before the first wildcard is an upper-case "Z"
  * Added the "bitvec" object for keeping track of which pages
    have been journalled. Improves speed and reduces memory
    consumption, especially for large database files.
  * Add the new sqlite3_result_error_code() API.
  * Convert the underlying virtual machine to be a register-based
    machine rather than a stack-based machine. The only
    user-visible change is in the output of EXPLAIN.
- Fix build for Tcl 8.5.
- Don't --enable-releasemode anymore, because it recently started
  putting the package version into the library name
  (libsqlite3-3.5.7.so.0.8.6)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 max@suse.de
- Fixed the tcl subpackage and adapted it to the new Tcl file
  system layout.
* Thu Jan 10 2008 lrupp@suse.de
- split of libsqlite3-0 package (Shared Library Packaging Policy)
- rename sqlite to sqlite3
* Tue Dec 18 2007 adrian@suse.de
- update to version 3.5.4
  From official changelog:
  * Fix a critical bug in UPDATE or DELETE that occurs when an
    OR REPLACE clause or a trigger causes rows in the same table to be
    deleted as side effects. (See ticket #2832.) The most likely result
    of this bug is a segmentation fault, though database corruption is
    a possibility.
  * Bring the processing of ORDER BY into compliance with the SQL
    standard for case where a result alias and a table column name are
    in conflict. Correct behavior is to prefer the result alias. Older
    versions of SQLite incorrectly picked the table column. (See ticket #2822.)
  * The VACUUM command preserves the setting of the legacy_file_format
    pragma. (Ticket #2804.)
  * Productize and officially support the group_concat() SQL function.
  * Better optimization of some IN operator expressions.
  * Add the ability to change the auto_vacuum status of a database by
    setting the auto_vaccum pragma and VACUUMing the database.
  * Prefix search in FTS3 is much more efficient.
  * Relax the SQL statement length restriction in the CLI so that the
    ".dump" output of databases with very large BLOBs and strings can
    be played back to recreate the database.
  * Other small bug fixes and optimizations.
* Fri Nov 30 2007 adrian@suse.de
- update to version 3.5.3
  * documentation has been removed from tar ball.
  From official changelog:
  * Fix a long-standing bug in INSERT INTO ... SELECT ... statements
    where the SELECT is compound.
  * Fix a long-standing bug in RAISE(IGNORE) as used in BEFORE triggers.
  * Fixed the operator precedence for the ~ operator.
  * Allow collating sequence names to be quoted.
  * Modify the TCL interface to use sqlite3_prepare_v2().
  * Fix multiple bugs that can occur following a malloc() failure.
  * sqlite3_step() returns SQLITE_MISUSE instead of crashing when
    called with a NULL parameter.
  * FTS3 now uses the SQLite memory allocator exclusively. The FTS3
    amalgamation can now be appended to the SQLite amalgamation to
    generate a super-amalgamation containing both.
  * The DISTINCT keyword now will sometimes use an INDEX if an
    appropriate index is available and the optimizer thinks its use
    might be advantageous.
* Mon Nov  5 2007 adrian@suse.de
- update to version 3.5.2
  From the official changelog:
  * The OS interface layer and the memory allocation subsystems in
    SQLite have been reimplemented. The published API is largely
    unchanged but the (unpublished) OS interface has been modified
    extensively. Applications that implement their own OS interface
    will require modification.
  * This is a large change. Approximately 10%% of the source code was
    modified.
  * Fix a long-standing bug that might cause database corruption if
    a disk-full error occurs in the middle of a transaction and that
    transaction is not rolled back.
* Thu Oct 18 2007 sbrabec@suse.cz
- Build with column metadata support, as required by libgda.
* Mon Aug 13 2007 adrian@suse.de
- call %%post/%%pre ldconfig again (#298292)
* Mon Aug  6 2007 adrian@suse.de
- update to version 3.4.1
  * Bugfix release to solve database corruption
  * remove static fts2 plugin patch, it is broken and get not used
  * Changelog from the release:
  - Fix a bug in VACUUM that can lead to  database corruption if two
    processes are connected to the database at the same time and one
    VACUUMs then the other then modifies the database.
  - The expression "+column" is now considered the same as "column" when
    computing the collating sequence to use on the expression.
  - In the TCL language interface, "@variable" instead of "$variable" always
    binds as a blob.
  - Added PRAGMA freelist_count for determining the current size of the
    freelist.
  - The  PRAGMA auto_vacuum=incremental setting is now persistent.
  - Add FD_CLOEXEC to all open files under unix.
  - Fix a bug in the  min()/max() optimization when applied to descending
    indices.
  - Make sure the TCL language interface works correctly with 64-bit integers
    on 64-bit machines.
  - Allow the value -9223372036854775808 as an integer literal in SQL
    statements.
  - Add the capability of "hidden" columns in virtual tables.
  - Use the macro SQLITE_PRIVATE (defaulting to "static") on all internal
    functions in the amalgamation.
  - Add pluggable tokenizers and ICU tokenization support to FTS2
  - Other minor bug fixes and documentation enhancements
* Tue Jun 26 2007 adrian@suse.de
- update to version 3.4.0
  WARNING: this version might cause incompatibilities due to new
    limits. These limits could be raised again, if we run in
    trouble, but let's follow upstream for now.
  * Two important bugfixes for database corruption.
  * New features like incremental BLOB I/O and incremental vacuum
* Fri Apr 27 2007 adrian@suse.de
- update to version 3.3.17
  * bug fix in forwards-compatibility logic of SQLite
* Thu Apr 19 2007 adrian@suse.de
- update to version 3.3.16
  * speed improvements were not enabled in .15 by accident
* Mon Apr 16 2007 adrian@suse.de
- update to version 3.3.15
  * speed improvements
  * new exclusive locking mode
- switch to -O3 now
- general spec file clean up
* Mon Feb 19 2007 adrian@suse.de
- update to version 3.3.13
  from the changelog:
  * Add a "fragmentation" measurement in the output of sqlite3_analyzer.
  * Add the COLLATE operator used to explicitly set the collating
    sequence used by an expression. This feature is considered
    experimental pending additional testing.
  * Allow up to 64 tables in a join - the old limit was 32.
  * Added two new experimental functions: randomBlob() and hex().
    Their intended use is to facilitate generating UUIDs.
  * Fix a problem where PRAGMA count_changes was causing incorrect
    results for updates on tables with triggers
  * Fix a bug in the ORDER BY clause optimizer for joins where
    the left-most table in the join is constrained by a UNIQUE index.
  * Fixed a bug in the "copy" method of the TCL interface.
  * Bug fixes in fts1 and fts2 modules.
* Mon Feb 12 2007 dmueller@suse.de
- fix library dependencies after loadable extensions were enabled
* Tue Feb  6 2007 dmacvicar@suse.de
- Enable support for loadable extensions
* Mon Feb  5 2007 max@suse.de
- Enable the fts1 and fts2 modules and link them in statically.
* Wed Jan 31 2007 adrian@suse.de
- update to version 3.3.12
  * further bugfixes, esp. for bugs introduced in 3.3.9
* Thu Jan 11 2007 adrian@suse.de
- update to version 3.3.10
  * pure bug fix release
* Tue Jan  9 2007 adrian@suse.de
- update to version 3.3.9
  * fixes database corruption "under obscure and difficult to
    reproduce circumstances".
  * new sqlite3_prepare v2() api (new header file)
* Mon Nov  6 2006 adrian@suse.de
- fix permissions of installed man page
* Mon Oct 16 2006 adrian@suse.de
- update to version 3.3.8
  * full-text search using the FTS1 module
  * minor bufixes
- two testcases got disabled, because they fail.
  We need to review the reason for that before shipping this package,
  but this package builds again at least.
* Wed Aug 23 2006 adrian@suse.de
- update to version 3.3.7
  * support for loadable extensions and virtual tables
  * minor bugfixes
* Thu May 18 2006 adrian@suse.de
- update to version 3.3.5
  Version 3.3 adds support for CHECK constraints, DESC indices,
  separate REAL and INTEGER column affinities, a new OS interface
  layer design, and many other changes.
  The file format for version 3.3 has changed slightly. SQLite 3.3
  will read and write legacy databases created with any prior
  version of SQLite 3. But databases created by version 3.3.0 will
  not be readable or writable by earlier versions of the SQLite
* Wed Mar 22 2006 schwab@suse.de
- Fix another 64bit bug.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 adrian@suse.de
- disable "same thread check". It is only needed with broken
  thread implementations and will be similar offered in sqlite 3.3
* Wed Jan  4 2006 adrian@suse.de
- update to version 3.2.8
  * bugfix release
* Tue Jan  3 2006 rguenthe@suse.de
- Correct 64bit issues causing x86_64 testsuite failures.
* Fri Dec  2 2005 jw@suse.de
- VERSION parsing back to normal.
  3002007 looks better than 3000000
* Mon Oct 24 2005 adrian@suse.de
- fix build for 64bit
* Mon Oct 17 2005 adrian@suse.de
- update to version 3.2.7
  * needed an additional fix for conflict.test
* Tue Aug 30 2005 jw@suse.de
- disabled a timing test. This fixes failed builds
  on heavy loaded autobuild hosts.
* Wed Jun 29 2005 jw@suse.de
- configure script fixed: VERSION was misparsed.
* Mon Jun 27 2005 max@suse.de
- Skip the testsuite if the underlaying file system doesn't
  support fsync() on directories (e.g. tmpfs).
* Tue Jun 21 2005 max@suse.de
- Update to version 3.2.2.
- Improved installation of the Tcl package.
* Thu Apr 21 2005 max@suse.de
- Disabling of certain tests for certain architectures does not
  seem to be needed anymore.
* Tue Apr 19 2005 ro@suse.de
- get patch to even apply
* Tue Apr 19 2005 max@suse.de
- Added a subpackage for the Tcl extension.
* Fri Apr  8 2005 adrian@suse.de
- update to version 3.2.1
* Tue Mar 29 2005 adrian@suse.de
- update to version 3.2.0
* Mon Feb 28 2005 adrian@suse.de
- update to version 3.1.3
  * a minor bugfix for VACUUM databases
  * to remain compatible with future 3.2 databases
- obsoletes a testsuite workaround
* Fri Feb 18 2005 adrian@suse.de
- fix library versioning
* Wed Feb 16 2005 adrian@suse.de
- update to version 3.1.2
  * contains a criticial bugsfix, which can corrupted the database
    when using the VACUUM command
* Mon Nov 29 2004 adrian@suse.de
- update to version 3.0.8
* Mon Nov 15 2004 adrian@suse.de
- add susehelp desktop file for developer documentation
* Mon Nov 15 2004 adrian@suse.de
- fix libdir path in .la file for lib64 systems
* Mon Oct 25 2004 adrian@suse.de
- enable utf-8 support
* Fri Jul 30 2004 adrian@suse.de
- run "make alltest"
* Thu Jul 29 2004 adrian@suse.de
- update to version 2.8.15
- disable wrong tcl test case on 64bit
* Mon Jun 21 2004 adrian@suse.de
- update to version 2.8.14
* Tue Jun  1 2004 adrian@suse.de
- package sqlite man page
* Fri Apr 23 2004 adrian@suse.de
- update to version 2.8.13
* Mon Mar  1 2004 adrian@suse.de
- disable format3 test case for ppc for now
* Sun Feb 29 2004 adrian@suse.de
- update to version 2.8.12
- add usual 64bit fixes
- add -fno-strict-aliasing
- disable bigfile test case due to limits in autobuild
* Thu Jan 22 2004 adrian@suse.de
- update to version 2.8.11
  * one testcase fails on ppc, our ppc people will have a look
* Mon Dec 29 2003 adrian@suse.de
- update to version 2.8.8
  * several 64 bit fixes have been merged, some more are needed now
- ignore some not exact matching float test cases on s390*
- enable threading support
* Tue Dec  2 2003 adrian@suse.de
- initial package of version 2.8.6
- a number of 64bit fixes
- some test cases got disabled, because they use an invalid Tcl
  Interface for 64bit
